/**
 * Test case for load.
 * Runs with mocha.
 */
"use strict";

const load = require('../lib/load.js'),
    assert = require('assert'),
    async = require('async'),
    coz = require('coz');

describe('load', () => {

    it('Load and render.', (done) => {
        let bud = load({
            type: 'sizes'
        }, '444', true);
        assert.ok(bud);
        assert.ok(bud.tmpl);
        bud.mkdirp = true;
        bud.path = __dirname + '/../tmp/foo/bar/baz.txt';
        coz.render(bud, function (err) {
            assert.ifError(err);
            done();
        });
    });

    it('Load for proto scss', (done) => {
        let tmpls = {
            'src/scss/variables/sizes.scss': {type: 'sizes'},
            'src/scss/variables/colors.scss': {type: 'colors'},
            'src/scss/attributes/float.scss': {type: 'attribute', key: 'float', values: ['left', 'right', 'none']},
            'src/scss/components/html.scss': {type: 'component', name: 'html'},
            'src/scss/components/body.scss': {type: 'component', name: 'body'},
            'src/scss/media/large-media.scss': {type: 'media', size: 'large'},
            'src/scss/media/medium-media.scss': {type: 'media', size: 'medium'},
            'src/scss/media/small-media.scss': {type: 'media', size: 'small'},
            'src/scss/base.scss': {
                type: 'base',
                media: ['large', 'medium', 'small'],
                components: ['html', 'body'],
                attributes: ['float']
            }
        };
        async.eachSeries(Object.keys(tmpls),(key, callback) => {
            let params = tmpls[key];
            let bud = load(params, '444', true);
            assert.ok(bud);
            bud.mkdirp = true;
            bud.path = `${__dirname}/../tmp/foo/bar/${key}`;
            coz.render(bud, function (err) {
                assert.ifError(err);
                callback(err);
            });
        }, (err) => {
            assert.ifError(err);
            done();
        });
    });
});

